@@ -23,10 +23,13 @@ from tencentcloud.chdfs.v20190718 import models
 class ChdfsClient(AbstractClient):
     _apiVersion = '2019-07-18'
     _endpoint = 'chdfs.tencentcloudapi.com'
+    _service = 'chdfs'
 
 
     def CreateAccessGroup(self, request):
-        """创建权限组。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        创建权限组。
 
         :param request: Request instance for CreateAccessGroup.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.CreateAccessGroupRequest`
@@ -54,7 +57,9 @@ class ChdfsClient(AbstractClient):
 
 
     def CreateAccessRules(self, request):
-        """批量创建权限规则，权限规则ID和创建时间无需填写。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        批量创建权限规则，权限规则ID和创建时间无需填写。
 
         :param request: Request instance for CreateAccessRules.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.CreateAccessRulesRequest`
@@ -82,7 +87,9 @@ class ChdfsClient(AbstractClient):
 
 
     def CreateFileSystem(self, request):
-        """创建文件系统（异步）。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        创建文件系统（异步）。
 
         :param request: Request instance for CreateFileSystem.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.CreateFileSystemRequest`
@@ -110,7 +117,9 @@ class ChdfsClient(AbstractClient):
 
 
     def CreateLifeCycleRules(self, request):
-        """批量创建生命周期规则，生命周期规则ID和创建时间无需填写。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        批量创建生命周期规则，生命周期规则ID和创建时间无需填写。
 
         :param request: Request instance for CreateLifeCycleRules.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.CreateLifeCycleRulesRequest`
@@ -138,7 +147,9 @@ class ChdfsClient(AbstractClient):
 
 
     def CreateMountPoint(self, request):
-        """创建文件系统挂载点，仅限于创建成功的文件系统。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        创建文件系统挂载点，仅限于创建成功的文件系统。
 
         :param request: Request instance for CreateMountPoint.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.CreateMountPointRequest`
@@ -166,7 +177,9 @@ class ChdfsClient(AbstractClient):
 
 
     def CreateRestoreTasks(self, request):
-        """批量创建回热任务，回热任务ID、状态和创建时间无需填写。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        批量创建回热任务，回热任务ID、状态和创建时间无需填写。
 
         :param request: Request instance for CreateRestoreTasks.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.CreateRestoreTasksRequest`
@@ -194,7 +207,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DeleteAccessGroup(self, request):
-        """删除权限组。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        删除权限组。
 
         :param request: Request instance for DeleteAccessGroup.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DeleteAccessGroupRequest`
@@ -222,7 +237,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DeleteAccessRules(self, request):
-        """批量删除权限规则。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        批量删除权限规则。
 
         :param request: Request instance for DeleteAccessRules.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DeleteAccessRulesRequest`
@@ -250,7 +267,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DeleteFileSystem(self, request):
-        """删除文件系统，不允许删除非空文件系统。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        删除文件系统，不允许删除非空文件系统。
 
         :param request: Request instance for DeleteFileSystem.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DeleteFileSystemRequest`
@@ -278,7 +297,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DeleteLifeCycleRules(self, request):
-        """批量删除生命周期规则。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        批量删除生命周期规则。
 
         :param request: Request instance for DeleteLifeCycleRules.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DeleteLifeCycleRulesRequest`
@@ -306,7 +327,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DeleteMountPoint(self, request):
-        """删除挂载点。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        删除挂载点。
 
         :param request: Request instance for DeleteMountPoint.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DeleteMountPointRequest`
@@ -334,7 +357,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DescribeAccessGroups(self, request):
-        """查看权限组列表。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        查看权限组列表。
 
         :param request: Request instance for DescribeAccessGroups.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DescribeAccessGroupsRequest`
@@ -362,7 +387,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DescribeAccessRules(self, request):
-        """通过权限组ID查看权限规则列表。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        通过权限组ID查看权限规则列表。
 
         :param request: Request instance for DescribeAccessRules.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DescribeAccessRulesRequest`
@@ -390,7 +417,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DescribeFileSystem(self, request):
-        """查看文件系统详细信息。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        查看文件系统详细信息。
 
         :param request: Request instance for DescribeFileSystem.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DescribeFileSystemRequest`
@@ -418,7 +447,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DescribeFileSystems(self, request):
-        """查看文件系统列表。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        查看文件系统列表。
 
         :param request: Request instance for DescribeFileSystems.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DescribeFileSystemsRequest`
@@ -446,7 +477,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DescribeLifeCycleRules(self, request):
-        """通过文件系统ID查看生命周期规则列表。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        通过文件系统ID查看生命周期规则列表。
 
         :param request: Request instance for DescribeLifeCycleRules.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DescribeLifeCycleRulesRequest`
@@ -474,7 +507,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DescribeMountPoint(self, request):
-        """查看挂载点详细信息。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        查看挂载点详细信息。
 
         :param request: Request instance for DescribeMountPoint.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DescribeMountPointRequest`
@@ -502,7 +537,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DescribeMountPoints(self, request):
-        """通过文件系统ID或者权限组ID查看挂载点列表。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        通过文件系统ID或者权限组ID查看挂载点列表。
 
         :param request: Request instance for DescribeMountPoints.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DescribeMountPointsRequest`
@@ -530,7 +567,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DescribeResourceTags(self, request):
-        """通过文件系统ID查看资源标签列表。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        通过文件系统ID查看资源标签列表。
 
         :param request: Request instance for DescribeResourceTags.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DescribeResourceTagsRequest`
@@ -558,7 +597,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DescribeRestoreTasks(self, request):
-        """通过文件系统ID查看回热任务列表。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        通过文件系统ID查看回热任务列表。
 
         :param request: Request instance for DescribeRestoreTasks.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DescribeRestoreTasksRequest`
@@ -586,7 +627,9 @@ class ChdfsClient(AbstractClient):
 
 
     def ModifyAccessGroup(self, request):
-        """修改权限组属性。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        修改权限组属性。
 
         :param request: Request instance for ModifyAccessGroup.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.ModifyAccessGroupRequest`
@@ -614,7 +657,9 @@ class ChdfsClient(AbstractClient):
 
 
     def ModifyAccessRules(self, request):
-        """批量修改权限规则属性，需要指定权限规则ID，支持修改权限规则地址、访问模式和优先级。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        批量修改权限规则属性，需要指定权限规则ID，支持修改权限规则地址、访问模式和优先级。
 
         :param request: Request instance for ModifyAccessRules.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.ModifyAccessRulesRequest`
@@ -642,7 +687,9 @@ class ChdfsClient(AbstractClient):
 
 
     def ModifyFileSystem(self, request):
-        """修改文件系统属性，仅限于创建成功的文件系统。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        修改文件系统属性，仅限于创建成功的文件系统。
 
         :param request: Request instance for ModifyFileSystem.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.ModifyFileSystemRequest`
@@ -670,7 +717,9 @@ class ChdfsClient(AbstractClient):
 
 
     def ModifyLifeCycleRules(self, request):
-        """批量修改生命周期规则属性，需要指定生命周期规则ID，支持修改生命周期规则名称、路径、转换列表和状态。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        批量修改生命周期规则属性，需要指定生命周期规则ID，支持修改生命周期规则名称、路径、转换列表和状态。
 
         :param request: Request instance for ModifyLifeCycleRules.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.ModifyLifeCycleRulesRequest`
@@ -698,7 +747,9 @@ class ChdfsClient(AbstractClient):
 
 
     def ModifyMountPoint(self, request):
-        """修改挂载点属性。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        修改挂载点属性。
 
         :param request: Request instance for ModifyMountPoint.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.ModifyMountPointRequest`
@@ -726,7 +777,9 @@ class ChdfsClient(AbstractClient):
 
 
     def ModifyResourceTags(self, request):
-        """修改资源标签列表，全量覆盖。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        修改资源标签列表，全量覆盖。
 
         :param request: Request instance for ModifyResourceTags.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.ModifyResourceTagsRequest`
